/**
 * @ignore
 * BEGIN HEADER
 *
 * Contains:        objectToArray
 * CVM-Role:        Utility function
 * Maintainer:      Hendrik Erz
 * License:         GNU GPL v3
 *
 * Description:     objectToArray converts a tree-like object with nested
 *                  properties into a one-dimensional array.
 *
 * END HEADER
 */

/**
 * Crunches a recursive object tree into a one-dimensional array.
 *
 * @param {any}    tree     The tree to be transformed
 * @param {string} traverse The property over which the recursion takes place
 * @param {any[]}  arr      An optional array to append to
 *
 * @return {any[]}          The flattened array
 */
export default function objectToArray (tree: any, traverse: string, arr: any[] = []): any[] {
  // Add the current tree
  arr.push(tree)

  if (traverse in tree && Array.isArray(tree[traverse]) && tree[traverse].length > 0) {
    // We have some children -> concat them
    for (let child of tree[traverse]) {
      arr = objectToArray(child, traverse, arr)
    }
  }

  return arr
}
